==> landers.angular-1.0.25.tgz: package/echarts.js <==
angular.module('Landers.echarts', [])
    .factory('EchartsService', function(){
        var planePath = 'path://M1705.06,1318.313v-89.254l-319.9-221.799l0.073-208.063c0.521-84.662-26.629-121.796-63.961-121.491c-37.332-0.305-64.482,36.829-63.961,121.491l0.073,208.063l-319.9,221.799v89.254l330.343-157.288l12.238,241.308l-134.449,92.931l0.531,42.034l175.125-42.917l175.125,42.917l0.531-42.034l-134.449-92.931l12.238-241.308L1705.06,1318.313z';
        // var color = ['#a6c84c', '#ffa022', '#46bee9'];
        var curveness = 0.2;

        var that;

        return {
            init : function(id){
                that = that || this;
                var chart = echarts.init(document.getElementById(id));
                $(window).resize(function(){chart.resize();});
                return chart;
            },
            map : {
                getPosByGeo : function(chartInstance, point, serie_index) {
                    var seriesModel = chartInstance.getModel();
                    if (seriesModel) {
                        var series = seriesModel.getSeriesByIndex(serie_index);
                        var coordSys = series.coordinateSystem;
                        var coord = coordSys.dataToPoint([point.lng, point.lat]);
                        return {left : coord[0], top : coord[1]};
                    } else {
                        console.log('seriesModel 为空！');
                        return {left : 0, top : 0};
                    }
                },
                getGeoByPos : function(chartInstance, coord, serie_index) {
                    var seriesModel = chartInstance.getModel();
                    if ( seriesModel ) {
                        var series = seriesModel.getSeriesByIndex(serie_index);
                        var coordSys = series.coordinateSystem;
                        var point = coordSys.dataToPoint([coord.x, coord.y]);
                        return {lng : point[0], lat : point[1]};
                    } else {
                        console.log('seriesModel 为空！');
                        return {lng : 0, lat : 0};
                    }
                },
                buildPath: function(from, tos) {
                    var ret = [];
                    angular.forEach(tos , function(to){
                        ret.push([{
                            coord: [to.lng, to.lat]
                        }, {
                            coord: [from.lng, from.lat]
                        }]);
                    });
                    return ret;
                },

                //轨迹
                track : function(name, dest, srcs) {
                    return {
                        name: name,
                        type: 'lines',
                        zlevel: 300,
                        effect: {
                            show: true,
                            period: 6,
                            trailLength: 0.1,
                            color: '#fff',
                            symbolSize: 3,
                        },
                        lineStyle: {
                            normal: {
                                // color: '#xxxxxx',
                                width: 0,
                                trailLength: 0.1,
                                curveness: curveness
                            }
                        },
                        data: that.map.buildPath(dest, srcs)
                    };
                },

                //线条
                line : function(dest, srcs, color) {
                    return {
                        name: dest.ip,
                        type: 'lines',
                        zlevel: 100,
                        effect: {
                            show: true,
                            period: 6,
                            trailLength: 0,
                            symbol: 'none',
                            symbolSize: 0
                        },
                        lineStyle: {
                            normal: {
                                color: color, //that.colors.src[type].line,
                                width: 1,
                                opacity: 0.1,
                                curveness: curveness
                            }
                        },
                        data: that.map.buildPath(dest, srcs)
                    };
                },

                //点
                dot : function(name, dots, color, zlevel) {
                    return {
                        name: name,
                        type: 'effectScatter',
                        coordinateSystem: 'geo',
                        legendHoverLink : true,
                        zlevel: zlevel,
                        rippleEffect: {
                            brushType: 'stroke'
                        },
                        label: {
                            normal: {
                                show: true,
                                position: 'right',
                                formatter: '{b}'
                            }
                        },
                        symbolSize: function (val) {
                            return val[2];
                        },
                        itemStyle: {
                            normal: {
                                color: color
                            }
                        },
                        data: dots.map(function (dot) {
                            return angular.extend({}, {
                                name: '',
                                // symbol : 'arrow',
                                value : [dot.lng, dot.lat, dot.level]
                            }, dot);
                        })
                    };
                },

                option : function(legends, series, opts){
                    opts = opts || {};
                    opts.legend = opts.legend || {};
                    return {
                        // backgroundColor: '#404a59',
                        title : {
                            text: '',
                            subtext: '',
                            left: 'center',
                            textStyle : {
                                color: '#fff'
                            }
                        },
                        tooltip : {
                            show : false,
                            trigger: 'item'
                            // formatter : function(item){
                            //     var data = item.data;
                            //     //只显示攻击目标的信息
                            //     if (data.kind == 'dest') {
                            //         var content = [];
                            //         content.push( '攻击流量：' + data.bps + 'Gbps');
                            //         content.push( '攻击报文：' + data.pps + 'pps');
                            //         return content.join('<br/>');
                            //     } else {
                            //         return null;
                            //     }
                            // }
                        },
                        legend: {
                            orient: 'vertical',
                            top: opts.legend.top,
                            bottom:opts.legend.bottom,
                            left: opts.legend.left,
                            right: opts.legend.right,
                            align: opts.legend.align,
                            // data:['北京 Top10', '上海 Top10', '广州 Top10'],
                            data: legends,
                            textStyle: {
                                color: '#fff'
                            },
                            selectedMode: 'single'
                        },
                        geo: {
                            map: 'world',
                            label: {
                                emphasis: {
                                    show: false
                                }
                            },
                            roam: true,
                            itemStyle: {
                                normal: {
                                    areaColor: '#323c48',
                                    borderColor: '#404a59'
                                },
                                emphasis: {
                                    areaColor: '#2a333d'
                                }
                            }
                        },
                        series: series
                    };
                }
            },

            // line : {
            //     option : function(categories, datas){
            //         return  {
            //             title: {
            //                 text: ''
            //             },
            //             tooltip : {
            //                 trigger: 'axis',
            //                 axisPointer : {            // 坐标轴指示器，坐标轴触发有效
            //                     type : 'shadow',        // 默认为直线，可选为：'line' | 'shadow'
            //                     animation: false
            //                 }
            //             },
            //             toolbox: {
            //                 feature: {
            //                     saveAsImage: {}
            //                 }
            //             },
            //             grid: {
            //                 left: '3%',
            //                 right: '4%',
            //                 bottom: '3%',
            //                 containLabel: true
            //             },
            //             xAxis : [
            //                 {
            //                     type : 'category',
            //                     boundaryGap : false,
            //                     data : categories
            //                 }
            //             ],
            //             yAxis : [
            //                 {
            //                     type : 'value'
            //                 }
            //             ],
            //             series :[
            //                 {
            //                     name:'',
            //                     type:'line',
            //                     // stack: '总量',
            //                     areaStyle: {normal: {}},
            //                     data:datas
            //                 }
            //             ]
            //         }
            //     }
            // },

            // bar : {
            //     option : function(categories, datas){
            //         return {
            //             color: ['#3398DB'],
            //             tooltip : {
            //                 trigger: 'axis',
            //                 axisPointer : {            // 坐标轴指示器，坐标轴触发有效
            //                     type : 'shadow'        // 默认为直线，可选为：'line' | 'shadow'
            //                 }
            //             },
            //             toolbox: {
            //                 feature: {
            //                     saveAsImage: {}
            //                 }
            //             },
            //             grid: {
            //                 left: '3%',
            //                 right: '4%',
            //                 bottom: '3%',
            //                 containLabel: true
            //             },
            //             xAxis : [
            //                 {
            //                     type : 'category',
            //                     data : categories,
            //                     axisTick: {
            //                         alignWithLabel: true
            //                     }
            //                 }
            //             ],
            //             yAxis : [
            //                 {
            //                     type : 'value'
            //                 }
            //             ],
            //             series : [
            //                 {
            //                     name:'',
            //                     type:'bar',
            //                     barWidth: '60%',
            //                     data:datas
            //                 }
            //             ]
            //         };
            //     }
            // }
        };
    });

==> landers.angular-1.0.36.tgz: package/echarts.js <==
angular.module('Landers.echarts', [])
    .factory('EchartsService', function(){
        var planePath = 'path://M1705.06,1318.313v-89.254l-319.9-221.799l0.073-208.063c0.521-84.662-26.629-121.796-63.961-121.491c-37.332-0.305-64.482,36.829-63.961,121.491l0.073,208.063l-319.9,221.799v89.254l330.343-157.288l12.238,241.308l-134.449,92.931l0.531,42.034l175.125-42.917l175.125,42.917l0.531-42.034l-134.449-92.931l12.238-241.308L1705.06,1318.313z';
        // var color = ['#a6c84c', '#ffa022', '#46bee9'];
        var curveness = 0.2;

        var that;

        return {
            init : function(id){
                that = that || this;
                var dom = document.getElementById(id);
                if (dom) {
                    var chart = echarts.init(dom);
                    $(window).resize(function(){
                        if (dom = document.getElementById(id)) {
                            chart.resize();
                        }
                    });
                    return chart;
                }
            },
            map : {
                getPosByGeo : function(chartInstance, point, serie_index) {
                    var seriesModel = chartInstance.getModel();
                    if (seriesModel) {
                        var series = seriesModel.getSeriesByIndex(serie_index);
                        var coordSys = series.coordinateSystem;
                        var coord = coordSys.dataToPoint([point.lng, point.lat]);
                        return {left : coord[0], top : coord[1]};
                    } else {
                        console.log('seriesModel 为空！');
                        return {left : 0, top : 0};
                    }
                },
                getGeoByPos : function(chartInstance, coord, serie_index) {
                    var seriesModel = chartInstance.getModel();
                    if ( seriesModel ) {
                        var series = seriesModel.getSeriesByIndex(serie_index);
                        var coordSys = series.coordinateSystem;
                        var point = coordSys.dataToPoint([coord.x, coord.y]);
                        return {lng : point[0], lat : point[1]};
                    } else {
                        console.log('seriesModel 为空！');
                        return {lng : 0, lat : 0};
                    }
                },
                buildPath: function(from, tos) {
                    var ret = [];
                    angular.forEach(tos , function(to){
                        ret.push([{
                            coord: [to.lng, to.lat]
                        }, {
                            coord: [from.lng, from.lat]
                        }]);
                    });
                    return ret;
                },

                //轨迹
                track : function(name, dest, srcs) {
                    return {
                        name: name,
                        type: 'lines',
                        zlevel: 300,
                        effect: {
                            show: true,
                            period: 6,
                            trailLength: 0.1,
                            color: '#fff',
                            symbolSize: 3,
                        },
                        lineStyle: {
                            normal: {
                                // color: '#xxxxxx',
                                width: 0,
                                trailLength: 0.1,
                                curveness: curveness
                            }
                        },
                        data: that.map.buildPath(dest, srcs)
                    };
                },

                //线条
                line : function(dest, srcs, color) {
                    return {
                        name: dest.ip,
                        type: 'lines',
                        zlevel: 100,
                        effect: {
                            show: true,
                            period: 6,
                            trailLength: 0,
                            symbol: 'none',
                            symbolSize: 0
                        },
                        lineStyle: {
                            normal: {
                                color: color, //that.colors.src[type].line,
                                width: 1,
                                opacity: 0.1,
                                curveness: curveness
                            }
                        },
                        data: that.map.buildPath(dest, srcs)
                    };
                },

                //点
                dot : function(name, dots, color, zlevel) {
                    return {
                        name: name,
                        type: 'effectScatter',
                        coordinateSystem: 'geo',
                        legendHoverLink : true,
                        zlevel: zlevel,
                        rippleEffect: {
                            brushType: 'stroke'
                        },
                        label: {
                            normal: {
                                show: true,
                                position: 'right',
                                formatter: '{b}'
                            }
                        },
                        symbolSize: function (val) {
                            return val[2];
                        },
                        itemStyle: {
                            normal: {
                                color: color
                            }
                        },
                        data: dots.map(function (dot) {
                            return angular.extend({}, {
                                name: '',
                                // symbol : 'arrow',
                                value : [dot.lng, dot.lat, dot.level]
                            }, dot);
                        })
                    };
                },

                option : function(legends, series, opts){
                    opts = opts || {};
                    opts.legend = opts.legend || {};
                    return {
                        // backgroundColor: '#404a59',
                        title : {
                            text: '',
                            subtext: '',
                            left: 'center',
                            textStyle : {
                                color: '#fff'
                            }
                        },
                        tooltip : {
                            show : false,
                            trigger: 'item'
                            // formatter : function(item){
                            //     var data = item.data;
                            //     //只显示攻击目标的信息
                            //     if (data.kind == 'dest') {
                            //         var content = [];
                            //         content.push( '攻击流量：' + data.bps + 'Gbps');
                            //         content.push( '攻击报文：' + data.pps + 'pps');
                            //         return content.join('<br/>');
                            //     } else {
                            //         return null;
                            //     }
                            // }
                        },
                        legend: {
                            orient: 'vertical',
                            top: opts.legend.top,
                            bottom:opts.legend.bottom,
                            left: opts.legend.left,
                            right: opts.legend.right,
                            align: opts.legend.align,
                            // data:['北京 Top10', '上海 Top10', '广州 Top10'],
                            data: legends,
                            textStyle: {
                                color: '#fff'
                            },
                            selectedMode: 'single'
                        },
                        geo: {
                            map: 'world',
                            label: {
                                emphasis: {
                                    show: false
                                }
                            },
                            roam: true,
                            itemStyle: {
                                normal: {
                                    areaColor: '#323c48',
                                    borderColor: '#404a59'
                                },
                                emphasis: {
                                    areaColor: '#2a333d'
                                }
                            }
                        },
                        series: series
                    };
                }
            },

            // line : {
            //     option : function(categories, datas){
            //         return  {
            //             title: {
            //                 text: ''
            //             },
            //             tooltip : {
            //                 trigger: 'axis',
            //                 axisPointer : {            // 坐标轴指示器，坐标轴触发有效
            //                     type : 'shadow',        // 默认为直线，可选为：'line' | 'shadow'
            //                     animation: false
            //                 }
            //             },
            //             toolbox: {
            //                 feature: {
            //                     saveAsImage: {}
            //                 }
            //             },
            //             grid: {
            //                 left: '3%',
            //                 right: '4%',
            //                 bottom: '3%',
            //                 containLabel: true
            //             },
            //             xAxis : [
            //                 {
            //                     type : 'category',
            //                     boundaryGap : false,
            //                     data : categories
            //                 }
            //             ],
            //             yAxis : [
            //                 {
            //                     type : 'value'
            //                 }
            //             ],
            //             series :[
            //                 {
            //                     name:'',
            //                     type:'line',
            //                     // stack: '总量',
            //                     areaStyle: {normal: {}},
            //                     data:datas
            //                 }
            //             ]
            //         }
            //     }
            // },

            // bar : {
            //     option : function(categories, datas){
            //         return {
            //             color: ['#3398DB'],
            //             tooltip : {
            //                 trigger: 'axis',
            //                 axisPointer : {            // 坐标轴指示器，坐标轴触发有效
            //                     type : 'shadow'        // 默认为直线，可选为：'line' | 'shadow'
            //                 }
            //             },
            //             toolbox: {
            //                 feature: {
            //                     saveAsImage: {}
            //                 }
            //             },
            //             grid: {
            //                 left: '3%',
            //                 right: '4%',
            //                 bottom: '3%',
            //                 containLabel: true
            //             },
            //             xAxis : [
            //                 {
            //                     type : 'category',
            //                     data : categories,
            //                     axisTick: {
            //                         alignWithLabel: true
            //                     }
            //                 }
            //             ],
            //             yAxis : [
            //                 {
            //                     type : 'value'
            //                 }
            //             ],
            //             series : [
            //                 {
            //                     name:'',
            //                     type:'bar',
            //                     barWidth: '60%',
            //                     data:datas
            //                 }
            //             ]
            //         };
            //     }
            // }
        };
    });
